#
# $Id: config.pm.sample,v 1.26 2013-03-23 14:16:32 dan Exp $
#
# Copyright (c) 2001-2007 DVL Software
#

package FreshPorts::Config;

use Cwd;

#
# This section contains local settings.  Change them to suit your environment.
#

# This configuration file is mostly for perl code, but where are our scripts
# etc?
$FreshPorts::Config::ScriptDir                  = '/usr/local/libexec/freshports';

# if set to non-zero, report-notification.pl report-security-notice.pl report-new-ports.pl will not send email
#
$FreshPorts::Config::ReportDebugging		= 1;

$FreshPorts::Config::FreshPortsURL		= 'https://example.freshports.org/';

$FreshPorts::Config::TimeAdjust			= '-10800 seconds';

# Values as found at https://www.postgresql.org/docs/current/static/libpq-ssl.html
# Possible values: disable allow prefer require verify-ca verify-ca
$FreshPorts::Config::ssl_mode                   = 'require';
$FreshPorts::Config::host			= '';
$FreshPorts::Config::dbname			= 'freshports.org';

# there are different users for different purposes

# the first user we created...
$FreshPorts::Config::user			= 'commits';
$FreshPorts::Config::password			= '';

# For the fp-listen daemon
$FreshPorts::Config::user_listening		= 'listening';
$FreshPorts::Config::password_listening		= '';

# For readonly connections
$FreshPorts::Config::user_readonly		= 'reading';
$FreshPorts::Config::password_readonly		= '';

$FreshPorts::Config::BaseDir			= '/var/db/freshports';

$FreshPorts::Config::scriptpath			= '/usr/local/libexec/freshports';

$FreshPorts::Config::mkdir_pkg			= 0;

$FreshPorts::Config::QueueBaseDir     		= $FreshPorts::Config::BaseDir . '/message-queues';

# This is where we chroot.  It also contains scripts for that jail.
$FreshPorts::Config::JailBaseDir = $FreshPorts::Config::BaseDir . '/ports-jail';

#
# where on disk is the ports tree?
#
$FreshPorts::Config::path_to_tree		= $FreshPorts::Config::JailBaseDir . '/var/db/repos';

#
# path to ports tree. no trailing slash. This is usually HEAD
#
$FreshPorts::Config::path_to_ports		= $FreshPorts::Config::path_to_tree . '/PORTS-head';

#
# where in the cvs tree are ports?
#
$FreshPorts::Config::ports_prefix		= 'ports';

$FreshPorts::Config::DailySummaryDir	= $FreshPorts::Config::BaseDir . "/cache/daily"; # no trailing /
$FreshPorts::Config::HourlySummaryDir	= $FreshPorts::Config::BaseDir . "/cache/html";

$FreshPorts::Config::CommitterNotify	= 0;	# Should we notify committers of problems?
$FreshPorts::Config::NotifyAdmin        = 1;	# Notify me

#
# Change only above. Do not change below.
#

#
# ensure we have the real path names here...
# otherwise we'll have trouble with determining relative pathnames
#
$FreshPorts::Config::scriptpath				= Cwd::abs_path($FreshPorts::Config::scriptpath);
$FreshPorts::Config::path_to_tree			= Cwd::abs_path($FreshPorts::Config::path_to_tree);	
$FreshPorts::Config::path_to_ports			= Cwd::abs_path($FreshPorts::Config::path_to_ports);

$FreshPorts::Config::email_server			= '127.1.0.202';
$FreshPorts::Config::email_port				= 25;

$FreshPorts::Config::SystemOwnerEmail		= 'dan@langille.org';

$FreshPorts::Config::JobWaiting                 = $FreshPorts::Config::BaseDir . '/signals/job_waiting';
$FreshPorts::Config::MovedFileFlag              = $FreshPorts::Config::BaseDir . '/signals/refresh_moved';
$FreshPorts::Config::UpdatingFileFlag           = $FreshPorts::Config::BaseDir . '/signals/refresh_updating';
$FreshPorts::Config::VuXMLFileFlag              = $FreshPorts::Config::BaseDir . '/signals/vuxml';
$FreshPorts::Config::RefreshCachFileFlag        = $FreshPorts::Config::BaseDir . '/signals/cache_needs_refresh';
$FreshPorts::Config::WWWENPortsCategoriesFlag   = $FreshPorts::Config::BaseDir . '/signals/www.en.ports.categories';

$FreshPorts::Config::PortsFreezeFile            = $FreshPorts::Config::BaseDir . '/signals/PortsFreezeIsInEffect';

# number of files in the ports tree
$FreshPorts::Config::PortsTreeCount	    	= $FreshPorts::Config::BaseDir . '/cache/html/PortsTreeCount';

#
# for ports caching
#
$FreshPorts::Config::CachingRoot            = $FreshPorts::Config::BaseDir . '/cache';

#
# tmp place for putting files needed by some special processing
#
$FreshPorts::Config::TMP	= $FreshPorts::Config::BaseDir . '/tmp';

#
# For fetching files from CVS
#
$FreshPorts::Config::CVS_Repository			= "http://www.freebsd.org/cgi/cvsweb.cgi";

#
# For fetching files from SVN
#
$FreshPorts::Config::SVN_Repository			= "http://svn.freebsd.org";

#
# various debugging settings
#
$FreshPorts::Config::Debug_FetchBeforeSavingPort = 0;

#
# for debugging....
#
#print "\$FreshPorts::Config::scriptpath    '$FreshPorts::Config::scriptpath'\n";
#print "\$FreshPorts::Config::path_to_tree  '$FreshPorts::Config::path_to_tree'\n";
#print "\$FreshPorts::Config::path_to_ports '$FreshPorts::Config::path_to_ports'\n";

# number of times to retry a failed fetch from cvsweb
$FreshPorts::Config::Fetch_Retry_Limit = 10;

# sleep this number of seconds between retries
$FreshPorts::Config::Fetch_Sleep_Time  = 120;

# various repo names that we follow
$FreshPorts::Config::Repo_DOC    = 'doc';
$FreshPorts::Config::Repo_PORTS  = 'ports';
$FreshPorts::Config::Repo_SRC    = 'src';

# the database file name root prefix fore each repo.
$FreshPorts::Config::DB_Root_Prefix_DOC    = '/doc';
$FreshPorts::Config::DB_Root_Prefix_PORTS  = '/ports';
$FreshPorts::Config::DB_Root_Prefix_SRC    = '/base';

$FreshPorts::Config::Ports_Default_Directory = $FreshPorts::Config::DB_Root_Prefix_PORTS . '/head';

# this is the path, within the CHROOT, to where we find the SVN directories.
$FreshPorts::Config::SVNBaseDir  = '/var/db/repos';

$FreshPorts::Config::JailConfigurePlist           = '/make-generate-plist.sh';
$FreshPorts::Config::JailCategoryDescrptionScript = '/make-category-comment.sh';
$FreshPorts::Config::JailDescr                    = '/make-descr.sh';
$FreshPorts::Config::JailDescrAndHomePage         = '/cat-descr.sh';
$FreshPorts::Config::JailMasterSitesScript        = '/make-master-sites-all.sh';
$FreshPorts::Config::JailPackageFlavors           = '/make-flavors-package-names.sh';
$FreshPorts::Config::JailPortScript               = '/make-port.sh';
$FreshPorts::Config::JailRealPath                 = '/realpath.sh';
$FreshPorts::Config::JailShowConfigScript         = '/make-showconfig.sh';
$FreshPorts::Config::JailUser                     = 'freshports';

1;
